@@ -107,7 +107,8 @@ class _VictorCombine(_VictorCommon):
         self.mol = Chem.Mol(self.params.mol)
         self.monster.positioned_mol = Chem.Mol(self.mol)
         # those lack correct Hs and names and charge!!
-        self.params.add_Hs()  # this re-embeds it.
+        #self.params.add_Hs()  # already done by rectify
+        self.params.add_conformer()
         self.params.convert_mol()
         # self.journal.warning(f'{self.long_name} - CHI HAS BEEN DISABLED')
         # self.params.CHI.data = []  # TODO check if chi fix is okay
